package Project::Easy::Distribution;

# $Id: Distribution.pm,v 1.1 2009/02/09 15:53:21 apla Exp $

use Class::Easy;

1;